// Copyright 3D Control Systems, Inc. All Rights Reserved 2017-2019.
// Built in San Francisco.

// This software is distributed under a commercial license for personal,
// educational, corporate or any other use.
// The software as a whole or any parts of it is prohibited for distribution or
// use without obtaining a license from 3D Control Systems, Inc.

// All software licenses are subject to the 3DPrinterOS terms of use
// (available at https://www.3dprinteros.com/terms-and-conditions/),
// and privacy policy (available at https://www.3dprinteros.com/privacy-policy/)

import QtQuick 2.7
import AppControls 1.0
import AppDialogs 1.0
import AppStyle 1.0
import "constants.js" as Constants

Item {
    id: accountInfoView

    ConfirmDialog {
        id: unbindPrinterConfirm
        z: 105
        anchors.centerIn: parent
        visible: false
        titleText: "Warning"
        titleColor: AppStyle.orange
        msg: qsTr("This will unbind this printer from your 3DPrinterOS account.\n Warning: ongoing print will be aborted!")
        yesText: qsTr("Unbind")
        noText: qsTr("Cancel")
        onYes: {
            coreModel.unbind()
            //TODO switch to register screen
            rootItem.showHead()
            rootItem.hideSetting()
        }
    }

    Component.onCompleted: {
        rootItem.hideHead()
    }

    Item {
        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
            bottom: footer.top
        }

        Row {
            spacing: 30
            anchors.centerIn: parent

            TextButton {
                width: 160
                height: 160
                text: qsTr("Unbind from cloud")
                onClicked: {
                    if (coreModel.state === Constants.States.PRINTING || coreModel.state === Constants.States.PAUSED) {
                        rootItem.showMessageDialog(Constants.MessageTypes.INFO, qsTr("Please, finish ongoing print before unbinding the printer from the Cloud."), "OK")
                        return
                    }

                    unbindPrinterConfirm.visible = true
                }
            }

            TextButton {
                width: 160
                height: 160
                text: qsTr("Check for updates")
                onClicked: {
                    coreModel.checkForUpdates()
                }
            }

            TextButton {
                width: 160
                height: 160
                text: coreModel.cameraState ? qsTr("Disable camera") : qsTr("Enable Camera")
                onClicked: {
                    if (coreModel.cameraState) {
                        coreModel.disableCamera()
                        return
                    }

                    coreModel.enableCamera()
                }
            }

            TextButton {
                width: 160
                height: 160
                text: qsTr("Reset printer board")
                onClicked: {
                    printerModel.resetBoard()
                }
            }
        }
    }

    Footer {
        id: footer
        nextBtnVisible: false
        anchors {
            bottom: parent.bottom
            right: parent.right
            left: parent.left
        }
        onBackClicked: {
            rootItem.showHead()
            rootItem.back()
        }
    }
}
