import QtQuick 2.0
import QtQuick.Controls 2.2

import AppStyle 1.0

/*
    Number TextField
    properties minValue, maxValue:
        if value out of range update TextField values

*/

TextField {
    id: control
    placeholderText: "_"
    width: 50
    height: 50
    horizontalAlignment: Text.AlignHCenter
    validator: RegExpValidator {
        regExp: /[+-]?([0-9]*[.])?[0-9]+/
    }
    color: AppStyle.textColor

    property real minValue: 0.1
    property real maxValue: 200

    signal validated(real numValue)

    background: Rectangle {
        implicitWidth: 50
        implicitHeight: 50

        color: control.enabled ? "transparent" : AppStyle.textColor
        border.color: control.enabled ? AppStyle.foreground : "transparent"
    }

    function validateField() {
        var numValue = parseInt(control.text);
        if (numValue) {
            control.text = numValue < minValue
                    ? minValue : (numValue > maxValue
                                  ? maxValue : numValue)
            validated(numValue)
            return
        }
    }

    onActiveFocusChanged: validateField()
    onEditingFinished: validateField()
}


